@@ -1,7 +1,7 @@
 package Media::Info::Mplayer;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -95,7 +95,7 @@ Media::Info::Mplayer - Return information on media file/URL, using mplayer
 
 =head1 VERSION
 
-This document describes version 0.04 of Media::Info::Mplayer (from Perl distribution Media-Info-Mplayer), released on 2015-08-17.
+This document describes version 0.05 of Media::Info::Mplayer (from Perl distribution Media-Info-Mplayer), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -133,7 +133,7 @@ L<Media::Info>
 
 =head2 get_media_info(%args) -> [status, msg, result, meta]
 
-{en_US Return information on media file/URL, using mplayer}.
+Return information on media file/URL, using mplayer.
 
 Arguments ('*' denotes required arguments):
 
@@ -141,7 +141,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<media>* => I<str>
 
-{en_US Media file/URL}.
+Media file/URL.
 
 =back
 
@@ -162,7 +162,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Media-Info
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Media-Info-Mplayer>.
+Source repository is at L<https://github.com/perlancar/perl-Media-Info-Mplayer>.
 
 =head1 BUGS
 
